#!/usr/bin/python3
"""This is the install hook file.

It is its own file because the rest of the hooks import landscape classes and
functions, and landscape is not installed until this hook runs.
"""

import subprocess
import sys

from charmhelpers import fetch
import charmhelpers.core.hookenv as hookenv


hooks = hookenv.Hooks()


@hooks.hook("install")
def install(fetch=fetch, hookenv=hookenv):
    charm_config = hookenv.config()
    # Deprecated option
    if charm_config.get('origin'):
        add_apt_source(charm_config.get('origin'), fetch=fetch)
    fetch.configure_sources(update=True)
    fetch.apt_install(['landscape-client'], fatal=True)

    data_path = charm_config.get("data-path")
    if not data_path:
        data_path = "/var/lib/landscape/client"

    result = subprocess.call(["landscape-config", "--init", "-d", data_path])
    if result != 0:
        result = subprocess.check_call([
            "install", "-o", "landscape", "-g", "root", "-m", "755", "-d",
            data_path])


def add_apt_source(url, fetch=fetch):
    """Add an apt source entry, with passed in key.

    This is a thin wrapper over the charmhelper "add_source" method to allow
    for the URLs to contain the key explicitely, like:
        - https://blah/blah|KEY
        - deb https://blah/blah|KEY
        - ppa:landscape/blah
    """
    key = None
    if "|" in url:
        # We have a particular key specified. Url = url without the key now.
        url, key = url.split("|", 1)  # Maximum of 1 split.
        if key == "":
            hookenv.log("Archive key for '%s' is empty.", level="WARNING")

    return fetch.add_source(url, key)


if __name__ == '__main__':
    try:
        sys.exit(hooks.execute(sys.argv))
    except hookenv.UnregisteredHookError as e:
        hookenv.log('Unknown hook {} - skipping.'.format(e))
